==> QupZilla-2.2.1.tar.xz: QupZilla-2.2.1/src/plugins/FlashCookieManager/translations/da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.1">
<context>
    <name>FCM_Dialog</name>
    <message>
        <location filename="../fcm_dialog.ui" line="14"/>
        <source>Flash Cookies</source>
        <translation>Flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="24"/>
        <source>Stored Flash Cookies</source>
        <translation>Lagrede Flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="45"/>
        <source>Find: </source>
        <translation>Find: </translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="73"/>
        <location filename="../fcm_dialog.ui" line="120"/>
        <location filename="../fcm_dialog.ui" line="130"/>
        <location filename="../fcm_dialog.ui" line="140"/>
        <location filename="../fcm_dialog.ui" line="256"/>
        <location filename="../fcm_dialog.cpp" line="151"/>
        <location filename="../fcm_dialog.cpp" line="152"/>
        <location filename="../fcm_dialog.cpp" line="153"/>
        <location filename="../fcm_dialog.cpp" line="154"/>
        <source>&lt;flash cookie not selected&gt;</source>
        <translation>&lt;flash-cookie ikke valgt&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="83"/>
        <source>Last Modified:</source>
        <translation>Sidst ændret:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="96"/>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="106"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="113"/>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <source>Origin:</source>
        <translation>Oprindelse:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="152"/>
        <source>Extracted latin1 strings:</source>
        <translation>Udtrukne latin1-strenge:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="182"/>
        <source>These flash cookies are stored on your computer:</source>
        <translation>Disse flash-cookies lagres på din computer:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="202"/>
        <source>Origin</source>
        <translation>Oprindelse</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="227"/>
        <source>Reload from disk</source>
        <translation>Genindlæs fra disk</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="240"/>
        <source>Path:</source>
        <translation>Sti:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="253"/>
        <source>Click to open containing folder</source>
        <translation>Klik for at åbne indeholdende mappe</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="276"/>
        <source>Remove all flash cookies</source>
        <translation>Fjern alle flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="283"/>
        <location filename="../fcm_dialog.cpp" line="156"/>
        <source>Remove flash cookies</source>
        <translation>Fjern flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="308"/>
        <source>Flash Cookies Filtering</source>
        <translation>Filtrering af flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="316"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie whitelist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Godkendelsesliste for flash-cookie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="348"/>
        <location filename="../fcm_dialog.ui" line="416"/>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="355"/>
        <location filename="../fcm_dialog.ui" line="423"/>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="364"/>
        <source>Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)</source>
        <translation>Flash-cookies fra disse oprindelser vil ikke blive slettet automatisk (brugeren vil heller ikke få notifikation om registrering af dem).</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="374"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie blacklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Blokeringsliste for flash-cookie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="381"/>
        <source>Flash cookies from these origins will be deleted without any notification.</source>
        <translation>Flash-cookies fra disse oprindelser vil blive slette uden notifikation.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="442"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="453"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Indstillinger for flash-cookie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="475"/>
        <source>Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.</source>
        <translation>Autotilstand: Flash-datamappen tjekkes regelmæssigt, og flash-cookies på blokeringsliste vil automatisk blive slettet.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="510"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; This settings are just applied to flash cookies, to manage HTTP cookies use &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies Manager&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bemærk:&lt;/span&gt; Disse indstillinger anvendes kun på flash-cookies. Brug &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies-håndtering&lt;/span&gt; til at håndtere HTTP-cookies. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="538"/>
        <source>Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.</source>
        <translation>Notifikation: Brugeren vil blive notificeret ved hver ny flash-cookie der ikke er på blokeringsliste og godkendelsesliste.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="565"/>
        <source>Delete all flash cookies on exit/start. (except those are in whitelist)</source>
        <translation>Slet alle flash-cookies ved afslut/start (undtagen dem der er på godkendelsesliste).</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="76"/>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="93"/>
        <source>Confirmation</source>
        <translation>Bekræftelse</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="94"/>
        <source>Are you sure you want to delete all flash cookies on your computer?</source>
        <translation>Er du sikker på, at du vil slette alle flash-cookies på din computer?</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="166"/>
        <location filename="../fcm_dialog.cpp" line="237"/>
        <source> (settings)</source>
        <translation> (indstillinger)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="169"/>
        <source> Byte</source>
        <translation> Byte</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="175"/>
        <source>Remove flash cookie</source>
        <translation>Fjern flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="241"/>
        <source> [new]</source>
        <translation> [ny]</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="375"/>
        <source>Add to whitelist</source>
        <translation>Tilføj til godkendelsesliste</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>Already whitelisted!</source>
        <translation>Allerede på godkendelsesliste</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <source>The server &quot;%1&quot; is already in blacklist, please remove it first.</source>
        <translation>Serveren &quot;%1&quot; er allerede på blokeringsliste, fjern den venligst først.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <location filename="../fcm_dialog.cpp" line="374"/>
        <source>Add to blacklist</source>
        <translation>Tilføj til blokeringsliste</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>The origin &quot;%1&quot; is already in whitelist, please remove it first.</source>
        <translation>Serveren &quot;%1&quot; er allerede på godkendelsesliste, fjern den venligst først.</translation>
    </message>
</context>
<context>
    <name>FCM_Notification</name>
    <message>
        <location filename="../fcm_notification.ui" line="45"/>
        <source>New flash cookie was detected!</source>
        <translation>Ny flash-cookie blev registreret!</translation>
    </message>
    <message>
        <location filename="../fcm_notification.ui" line="52"/>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="34"/>
        <source>A new flash cookie was detected</source>
        <translation>En ny flash-cookie blev registreret</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="37"/>
        <source>%1 new flash cookies were detected</source>
        <translation>%1 nye flash-cookies blev registrerede</translation>
    </message>
</context>
<context>
    <name>FCM_Plugin</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="129"/>
        <source>Flash Cookie Manager</source>
        <translation>Håndtering af flash-cookie</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="357"/>
        <source>Show Flash Cookie Manager</source>
        <translation>Vis håndtering af flash-cookie</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="439"/>
        <source>!default</source>
        <translation>!standard</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="451"/>
        <source>!other</source>
        <translation>!anden</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.5.tar.xz: QupZilla-2.2.5/src/plugins/FlashCookieManager/translations/da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.1">
<context>
    <name>FCM_Button</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="58"/>
        <source>Flash Cookie Manager button</source>
        <translation>Håndtering af flash-cookie-knap</translation>
    </message>
</context>
<context>
    <name>FCM_Dialog</name>
    <message>
        <location filename="../fcm_dialog.ui" line="14"/>
        <source>Flash Cookies</source>
        <translation>Flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="24"/>
        <source>Stored Flash Cookies</source>
        <translation>Lagrede Flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="45"/>
        <source>Find: </source>
        <translation>Find: </translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="73"/>
        <location filename="../fcm_dialog.ui" line="120"/>
        <location filename="../fcm_dialog.ui" line="130"/>
        <location filename="../fcm_dialog.ui" line="140"/>
        <location filename="../fcm_dialog.ui" line="256"/>
        <location filename="../fcm_dialog.cpp" line="151"/>
        <location filename="../fcm_dialog.cpp" line="152"/>
        <location filename="../fcm_dialog.cpp" line="153"/>
        <location filename="../fcm_dialog.cpp" line="154"/>
        <source>&lt;flash cookie not selected&gt;</source>
        <translation>&lt;flash-cookie ikke valgt&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="83"/>
        <source>Last Modified:</source>
        <translation>Sidst ændret:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="96"/>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="106"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="113"/>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <source>Origin:</source>
        <translation>Oprindelse:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="152"/>
        <source>Extracted latin1 strings:</source>
        <translation>Udtrukne latin1-strenge:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="182"/>
        <source>These flash cookies are stored on your computer:</source>
        <translation>Disse flash-cookies lagres på din computer:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="202"/>
        <source>Origin</source>
        <translation>Oprindelse</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="227"/>
        <source>Reload from disk</source>
        <translation>Genindlæs fra disk</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="240"/>
        <source>Path:</source>
        <translation>Sti:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="253"/>
        <source>Click to open containing folder</source>
        <translation>Klik for at åbne indeholdende mappe</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="276"/>
        <source>Remove all flash cookies</source>
        <translation>Fjern alle flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="283"/>
        <location filename="../fcm_dialog.cpp" line="156"/>
        <source>Remove flash cookies</source>
        <translation>Fjern flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="308"/>
        <source>Flash Cookies Filtering</source>
        <translation>Filtrering af flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="316"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie whitelist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Godkendelsesliste for flash-cookie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="348"/>
        <location filename="../fcm_dialog.ui" line="416"/>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="355"/>
        <location filename="../fcm_dialog.ui" line="423"/>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="364"/>
        <source>Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)</source>
        <translation>Flash-cookies fra disse oprindelser vil ikke blive slettet automatisk (brugeren vil heller ikke få notifikation om registrering af dem).</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="374"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie blacklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Blokeringsliste for flash-cookie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="381"/>
        <source>Flash cookies from these origins will be deleted without any notification.</source>
        <translation>Flash-cookies fra disse oprindelser vil blive slette uden notifikation.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="442"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="453"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Indstillinger for flash-cookie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="475"/>
        <source>Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.</source>
        <translation>Autotilstand: Flash-datamappen tjekkes regelmæssigt, og flash-cookies på blokeringsliste vil automatisk blive slettet.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="510"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; This settings are just applied to flash cookies, to manage HTTP cookies use &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies Manager&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bemærk:&lt;/span&gt; Disse indstillinger anvendes kun på flash-cookies. Brug &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies-håndtering&lt;/span&gt; til at håndtere HTTP-cookies. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="538"/>
        <source>Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.</source>
        <translation>Notifikation: Brugeren vil blive notificeret ved hver ny flash-cookie der ikke er på blokeringsliste og godkendelsesliste.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="565"/>
        <source>Delete all flash cookies on exit/start. (except those are in whitelist)</source>
        <translation>Slet alle flash-cookies ved afslut/start (undtagen dem der er på godkendelsesliste).</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="76"/>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="93"/>
        <source>Confirmation</source>
        <translation>Bekræftelse</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="94"/>
        <source>Are you sure you want to delete all flash cookies on your computer?</source>
        <translation>Er du sikker på, at du vil slette alle flash-cookies på din computer?</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="166"/>
        <location filename="../fcm_dialog.cpp" line="237"/>
        <source> (settings)</source>
        <translation> (indstillinger)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="169"/>
        <source> Byte</source>
        <translation> Byte</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="175"/>
        <source>Remove flash cookie</source>
        <translation>Fjern flash-cookies</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="241"/>
        <source> [new]</source>
        <translation> [ny]</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="375"/>
        <source>Add to whitelist</source>
        <translation>Tilføj til godkendelsesliste</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>Already whitelisted!</source>
        <translation>Allerede på godkendelsesliste</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <source>The server &quot;%1&quot; is already in blacklist, please remove it first.</source>
        <translation>Serveren &quot;%1&quot; er allerede på blokeringsliste, fjern den venligst først.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <location filename="../fcm_dialog.cpp" line="374"/>
        <source>Add to blacklist</source>
        <translation>Tilføj til blokeringsliste</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>The origin &quot;%1&quot; is already in whitelist, please remove it first.</source>
        <translation>Serveren &quot;%1&quot; er allerede på godkendelsesliste, fjern den venligst først.</translation>
    </message>
</context>
<context>
    <name>FCM_Notification</name>
    <message>
        <location filename="../fcm_notification.ui" line="45"/>
        <source>New flash cookie was detected!</source>
        <translation>Ny flash-cookie blev registreret!</translation>
    </message>
    <message>
        <location filename="../fcm_notification.ui" line="52"/>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="34"/>
        <source>A new flash cookie was detected</source>
        <translation>En ny flash-cookie blev registreret</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="37"/>
        <source>%1 new flash cookies were detected</source>
        <translation>%1 nye flash-cookies blev registrerede</translation>
    </message>
</context>
<context>
    <name>FCM_Plugin</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="147"/>
        <location filename="../fcm_plugin.cpp" line="377"/>
        <source>Flash Cookie Manager</source>
        <translation>Håndtering af flash-cookie</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="378"/>
        <source>Show Flash Cookie Manager</source>
        <translation>Vis håndtering af flash-cookie</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="459"/>
        <source>!default</source>
        <translation>!standard</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="471"/>
        <source>!other</source>
        <translation>!anden</translation>
    </message>
</context>
</TS>
